<?php
/*
Plugin Name: My portfolio
Plugin URI: http://www.my-portfolio.com 
Version: 1.0
Description: Declares custom post type "project" for Potfolio.
Author: IMAKER IT
Author URI: http://www.my-portfolio.com 
License: My free license
*/


/* Registered a custom post type with slug "project" */
function imaker_projects() {
	// Set UI labels for Custom Post Type
	$labels = array(
		'name' => _x('Portfolio', 'post type general name'),
		'singular_name' => _x('Project', 'post type singular name'),
		'add_new' => _x('Add New', 'project'),
		'add_new_item' => __('Add new project'),
		'edit_item' => __('Edit project'),
		'new_item' => __('New project'),
		'all_items' => __('All projects'),
		'view_item' => __('View project'),
		'search_items' => __('Search project'),
		'not_found' =>	__('No projects found'),
		'not_found_in_trash' => __('No projects found in Trash'), 
		'parent_item_colon' => __('Parent projects'),
		'menu_name' => __('Portfolio')
	);
	
	// Set other options for Custom Post Type
	$args = array(
		'labels' => $labels,
		'hierarchical' => true,
		'description' => 'Project Posts',
		'supports' => array( 'title', 'editor', 'thumbnail' ),
		'taxonomies' => array( 'project_category', 'post_tag' ),
		'show_ui' => true, 
		'show_in_menu' => true, 
		'menu_position' => null,
		'menu_icon' => 'dashicons-list-view',
		'show_in_nav_menus' => true,
		'publicly_queryable' => true,
		'exclude_from_search' => false,
		'query_var' => true,
		'can_export' => true,
		'rewrite' => array('slug'=>'portfolio/%project_category%', 'with_front'=>FALSE),
		'public' => true,
		'has_archive' => 'projects', 
		'capability_type' => 'post',
	); 
	register_post_type('project',$args);
}
add_action( 'init', 'imaker_projects' );


/* Set taxonomy for custom post type */
function my_taxonomy() {
	register_taxonomy(
		'project_category',					//The name of the taxonomy 
		'project',							//Post type name
		array(
			'hierarchical' => true,
			'label' => 'Categories',		//Display name
			'query_var' => true,
			'rewrite' => array(
				'slug' => 'category',		//The base slug
				'with_front' => false		//Don't display the category base before 
			),
			'show_admin_column' => true,	//Display column in Backend
		)
	);
}
add_action( 'init', 'my_taxonomy');


/* Changed permalink */
function filter_post_type_link($link, $post) {
	if ($post->post_type != 'project')
		return $link;

	if ($cats = get_the_terms($post->ID, 'project_category'))
		$link = str_replace('%project_category%', array_pop($cats)->slug, $link);
	return $link;
}
add_filter('post_type_link', 'filter_post_type_link', 10, 2);


/* Set default category, if post has not category */
function default_taxonomy_term( $post_id, $post ) {
	if ( 'publish' === $post->post_status ) {
		$defaults = array(
			'project_category' => array('other'),
		);
		$taxonomies = get_object_taxonomies( $post->post_type );
		foreach ( (array) $taxonomies as $taxonomy ) {
			$terms = wp_get_post_terms( $post_id, $taxonomy );
			if ( empty( $terms ) && array_key_exists( $taxonomy, $defaults ) ) {
				wp_set_object_terms( $post_id, $defaults[$taxonomy], $taxonomy );
			}
		}
	}
}
add_action( 'save_post', 'default_taxonomy_term', 100, 2 );
